@@ -11,15 +11,7 @@ describe Dalli::Protocol::ValueCompressor do
         let(:options) { {} }
 
         it 'defaults to true' do
-          assert subject.compress_by_default?
-        end
-
-        describe 'when the deprecated compression option is used' do
-          let(:options) { { compression: false } }
-
-          it 'overrides the default' do
-            refute subject.compress_by_default?
-          end
+          assert_predicate subject, :compress_by_default?
         end
       end
 
@@ -27,15 +19,7 @@ describe Dalli::Protocol::ValueCompressor do
         let(:options) { { compress: true } }
 
         it 'is true' do
-          assert subject.compress_by_default?
-        end
-
-        describe 'when the deprecated compression option is used' do
-          let(:options) { { compress: true, compression: false } }
-
-          it 'does not override the explicit compress options' do
-            assert subject.compress_by_default?
-          end
+          assert_predicate subject, :compress_by_default?
         end
       end
 
@@ -43,15 +27,7 @@ describe Dalli::Protocol::ValueCompressor do
         let(:options) { { compress: false } }
 
         it 'is false' do
-          refute subject.compress_by_default?
-        end
-
-        describe 'when the deprecated compression option is used' do
-          let(:options) { { compress: false, compression: true } }
-
-          it 'does not override the explicit compress options' do
-            refute subject.compress_by_default?
-          end
+          refute_predicate subject, :compress_by_default?
         end
       end
     end
@@ -61,7 +37,7 @@ describe Dalli::Protocol::ValueCompressor do
         let(:options) { {} }
 
         it 'defaults to Dalli::Compressor' do
-          assert_equal subject.compressor, ::Dalli::Compressor
+          assert_equal subject.compressor, Dalli::Compressor
         end
       end
 
@@ -80,7 +56,7 @@ describe Dalli::Protocol::ValueCompressor do
         let(:options) { {} }
 
         it 'defaults to 4 KB' do
-          assert_equal subject.compression_min_size, 4096
+          assert_equal(4096, subject.compression_min_size)
         end
       end
 
@@ -116,6 +92,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -127,6 +104,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -138,6 +116,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -153,6 +132,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -164,6 +144,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -175,6 +156,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -195,6 +177,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -207,6 +190,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -218,6 +202,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -233,6 +218,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -245,6 +231,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -256,6 +243,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -280,6 +268,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -291,6 +280,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -302,6 +292,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -317,6 +308,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -328,6 +320,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -339,6 +332,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -359,6 +353,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -371,6 +366,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -382,6 +378,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -397,6 +394,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -409,6 +407,7 @@ describe Dalli::Protocol::ValueCompressor do
               it 'compresses the argument' do
                 compressor.expect :compress, compressed_dummy, [raw_value]
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, compressed_dummy
                 assert_equal newbitflags, (bitflags | 0x2)
                 compressor.verify
@@ -420,6 +419,7 @@ describe Dalli::Protocol::ValueCompressor do
 
               it 'does not compress the argument' do
                 val, newbitflags = vc.store(raw_value, req_options, bitflags)
+
                 assert_equal val, raw_value
                 assert_equal newbitflags, bitflags
                 compressor.verify
@@ -443,7 +443,8 @@ describe Dalli::Protocol::ValueCompressor do
       it 'should return the value without decompressing' do
         bitflags = rand(32)
         bitflags &= 0xFFFD
-        assert_equal bitflags & 0x2, 0
+
+        assert_equal(0, bitflags & 0x2)
         assert_equal vc.retrieve(raw_value, bitflags), raw_value
         compressor.verify
       end
@@ -457,7 +458,8 @@ describe Dalli::Protocol::ValueCompressor do
         compressor.expect :decompress, decompressed_dummy, [raw_value]
         bitflags = rand(32)
         bitflags |= 0x2
-        assert_equal bitflags & 0x2, 0x2
+
+        assert_equal(0x2, bitflags & 0x2)
         assert_equal vc.retrieve(raw_value, bitflags), decompressed_dummy
         compressor.verify
       end
@@ -469,13 +471,15 @@ describe Dalli::Protocol::ValueCompressor do
 
       it 'translates that into a UnmarshalError' do
         error = ->(_arg) { raise Zlib::Error, error_message }
-        ::Dalli::Compressor.stub :decompress, error do
+        Dalli::Compressor.stub :decompress, error do
           bitflags = rand(32)
           bitflags |= 0x2
-          assert_equal bitflags & 0x2, 0x2
+
+          assert_equal(0x2, bitflags & 0x2)
           exception = assert_raises Dalli::UnmarshalError do
             vc.retrieve(raw_value, bitflags)
           end
+
           assert_equal exception.message, "Unable to uncompress value: #{error_message}"
         end
       end
